==> Pyrogram-1.0.3-py3-none-any.whl: pyrogram/raw/base/privacy_rule.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

PrivacyRule = Union[raw.types.PrivacyValueAllowAll, raw.types.PrivacyValueAllowChatParticipants, raw.types.PrivacyValueAllowContacts, raw.types.PrivacyValueAllowUsers, raw.types.PrivacyValueDisallowAll, raw.types.PrivacyValueDisallowChatParticipants, raw.types.PrivacyValueDisallowContacts, raw.types.PrivacyValueDisallowUsers]


# noinspection PyRedeclaration
class PrivacyRule(TLObject):  # type: ignore
    """This base type has 8 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`PrivacyValueAllowAll <pyrogram.raw.types.PrivacyValueAllowAll>`
            - :obj:`PrivacyValueAllowChatParticipants <pyrogram.raw.types.PrivacyValueAllowChatParticipants>`
            - :obj:`PrivacyValueAllowContacts <pyrogram.raw.types.PrivacyValueAllowContacts>`
            - :obj:`PrivacyValueAllowUsers <pyrogram.raw.types.PrivacyValueAllowUsers>`
            - :obj:`PrivacyValueDisallowAll <pyrogram.raw.types.PrivacyValueDisallowAll>`
            - :obj:`PrivacyValueDisallowChatParticipants <pyrogram.raw.types.PrivacyValueDisallowChatParticipants>`
            - :obj:`PrivacyValueDisallowContacts <pyrogram.raw.types.PrivacyValueDisallowContacts>`
            - :obj:`PrivacyValueDisallowUsers <pyrogram.raw.types.PrivacyValueDisallowUsers>`
    """

    QUALNAME = "pyrogram.raw.base.PrivacyRule"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/privacy_rule.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

PrivacyRule = Union[raw.types.PrivacyValueAllowAll, raw.types.PrivacyValueAllowChatParticipants, raw.types.PrivacyValueAllowContacts, raw.types.PrivacyValueAllowUsers, raw.types.PrivacyValueDisallowAll, raw.types.PrivacyValueDisallowChatParticipants, raw.types.PrivacyValueDisallowContacts, raw.types.PrivacyValueDisallowUsers]


# noinspection PyRedeclaration
class PrivacyRule:  # type: ignore
    """This base type has 8 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`PrivacyValueAllowAll <pyrogram.raw.types.PrivacyValueAllowAll>`
            - :obj:`PrivacyValueAllowChatParticipants <pyrogram.raw.types.PrivacyValueAllowChatParticipants>`
            - :obj:`PrivacyValueAllowContacts <pyrogram.raw.types.PrivacyValueAllowContacts>`
            - :obj:`PrivacyValueAllowUsers <pyrogram.raw.types.PrivacyValueAllowUsers>`
            - :obj:`PrivacyValueDisallowAll <pyrogram.raw.types.PrivacyValueDisallowAll>`
            - :obj:`PrivacyValueDisallowChatParticipants <pyrogram.raw.types.PrivacyValueDisallowChatParticipants>`
            - :obj:`PrivacyValueDisallowContacts <pyrogram.raw.types.PrivacyValueDisallowContacts>`
            - :obj:`PrivacyValueDisallowUsers <pyrogram.raw.types.PrivacyValueDisallowUsers>`
    """

    QUALNAME = "pyrogram.raw.base.PrivacyRule"
